$VAR1 = [
  {
    'Person' => [
      [
        'name',
        'age',
        'email'
      ],
      [
        'John',
        '40',
        'john@nowhere.com'
      ],
      [
        'Apo',
        '31',
        'pate@work.com'
      ],
      [
        'Alex',
        '31',
        'alex@work.org'
      ],
      [
        'Alexandra',
        '38',
        'alex@home.org'
      ],
      [
        'Rudolf',
        '72',
        undef,
      ],
    ],
  },
];